@@ -1,9 +1,10 @@
-from treetopper._constants import (math,
-                                   GRADE_NAMES,
-                                   LOG_LENGTHS,
-                                   OFFICIAL_GRADES,
-                                   SCRIBNER_DICT)
-
+from treetopper._constants import (
+    math,
+    GRADE_NAMES,
+    LOG_LENGTHS,
+    OFFICIAL_GRADES,
+    SCRIBNER_DICT
+)
 
 
 class Log(object):
@@ -31,11 +32,9 @@ class Log(object):
         self.bf_ac = self.bf * self.lpa
         self.cf_ac = self.cf * self.lpa
 
-
         self.grade_name = GRADE_NAMES[self.grade]
         self.length_range = self._get_length_range()
 
-
     def __getitem__(self, attribute: str):
         return self.__dict__[attribute]
 
@@ -48,7 +47,7 @@ class Log(object):
     def _calc_top_dib(self):
         """Uses the Timber Class' stem taper equation to calculate the top diameter inside bark (DIB) of the log
            from the stem_height argument"""
-        return int(math.floor(self.tree.equation(self.tree.dbh, self.tree.height, self.stem_height, **self.tree.coef[1])))
+        return self.tree.get_any_dib(self.stem_height)
 
     def _calc_log_grade(self):
         """Used when the Timber Class is TimberQuick, it will get the grade of the log based on species, minimum log lengths,
